#
# spec file for package helm-mirror
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Project name when using go tooling.
%define project github.com/openSUSE/helm-mirror

Name:           helm-mirror
Version:        0.3.0
Release:        lp151.2.3.1
Summary:        Tool to mirror Helm repositories
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/openSUSE/helm-mirror
Source:         %{name}-%{version}.tar.gz
BuildRequires:  go >= 1.11.3
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.11
Requires(post): %fillup_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This utility mirrors Helm repositories to a local directory and it
can extract used container images.

%prep
%setup -q

%build

# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
rm -rf $HOME/go/src/%{project}/*
cp -avr * $HOME/go/src/%{project}

export VERSION=$(sed -n -e 's/version:[ "]*\([^"]*\).*/\1/p' plugin.yaml)
if [ "$VERSION" != "%{version}" ]; then
  VERSION="%{version}_suse"
fi

make VERSION="$VERSION" mirror
make doc

%install
# Install the plugin.
install -D -m 0755 ./bin/helm-mirror "%{buildroot}/%{_bindir}/%{name}"

# Install all of the docs.
for file in doc/man/*.1; do
  install -D -m 0644 $file "%{buildroot}/%{_mandir}/man1/$(basename $file)"
done

%files
%defattr(-,root,root)
%doc README.md LICENSE doc/*
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*

%changelog
* Mon Oct  7 2019 Vicente Zepeda Mas <vzepedamas@suse.com>
  [#]# v0.3.0
- New features: get latest and specific charts
  - Getting charts now only downloads the altest versions of the charts.
  - The --all-versions flags allows to download all versions of the charts.
  - The flags --chart-name and --chart-version allow the user to only get the desired chart.
  fix bsc#1153244
* Fri Jul 12 2019 Daniel Orf <dorf@suse.com>
  [#]# v0.2.4
- updated release steps
- updated install script
  [#]# v0.2.3
- fixes issue while getting the latest release
  [#]# v0.2.2
- fixes issue with go module when installing with `helm plugin install`
* Fri Jan  4 2019 Vicente Zepeda <vzepedamas@suse.com>
  [#]# v0.2.1
- fixes empty archive files
- usage of ignore-errors flag
  fix bsc#1120762
* Tue Dec 18 2018 Vicente Zepeda <vzepedamas@suse.com>
- Update go requirements to >= go1.11.3 to fix
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
    go#29233 crypto/x509: CPU denial of service
* Wed Dec 12 2018 Vicente Zepeda <vzepedamas@suse.com>
  upgrade to the latest go version so we build with a supported go
* Tue Dec  4 2018 Vicente Zepeda <vzepedamas@suse.com>
  [#]# v0.2.0
  [#]## Added
- `mirror inspect-images` flag `--output` usage updated, flag `--file-name` no longer needed.
  - `-o file=filename`
  - `-o json=filename.json`
  - `-o yaml=filename.yaml`
  - `-o skopeo=filename.yaml`
- `helm-mirror` has a new flag `--new-root-url` new root url of the chart repository.
  (eg: `https://mirror.local.lan/charts`). This will allow users to set the name of
  their mirror server when getting all the charts.
- `downloaded-index.yaml` file changes it's name to `index.yaml` to allow users to host quickly
  a mirror chart server.
  fix bsc#1117783
* Sun Nov 11 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Fri Oct 12 2018 vzepedamas@suse.com
  [#]# v0.1.0
  [#]## Added
- `mirror [chart-repo] [target-folder]` this command takes a chart repository and downloads all
  chart found in there and downloads them to a local target folder.
- `mirror inspect-images [target]` this command takes the target and extracts all container
  images being used in it. It can be a single chart or a folder with multiple charts. If
  some values are not present to process the chart you can use `--ignore-errors` flag to
  render the charts and get the container image anyway. (this can output inconsistent data)
- Use Helm configuration settings for Chart Repository.
  - --ca-file
  - --cert-file
  - --key-file
  - --password
  - --username
- CI steps with [Travis CI](https://travis-ci.org) and Code Coverage with [CodeCov](https://codecov.io)
  (fate#326810)
  fix bsc#1116182
